@@ -250,18 +250,19 @@ static void
 OpenPort(int new, int old)
 {
   extern char *portlist[];
+  static char srx[] = "TTY:SRX";
 
   if(serial)
     {
       Sw_Serial(OFF);
       p_close(serial);
-      if(old == 3)
+      if(!p_scmpi(portlist[old], srx))
         p_devdel(portlist[old], E_PDD);
       serial = 0;
     }
   if(new)
     {
-      if(new == 3) /* 3Fax, experimental */
+      if(!p_scmpi(portlist[new], srx)) /* 3Fax, experimental */
         {
 	  if(Check(p_loadpdd("loc::c:\\img\\sys$a550.pdd"),"load 3Fax driver"))
 	    {
@@ -864,7 +865,8 @@ void ParseKey (UWORD key, UBYTE modifier) {
 
 	    flow = (pm_xonxoff ? 1 : (pm_nortscts ? 3 : 2));
             if (   uOpenDialog (cmds[5]+1)
-                || uAddChoiceList ("Port", &port, rl[0],rl[1],rl[2],rl[3],NULL)
+                || uAddChoiceList ("Port", &port,
+				rl[0],rl[1],rl[2],rl[3],rl[4], NULL)
                 || uAddChoiceList ("Baud rate", &baud,
 				bl[0],bl[1],bl[2],bl[3],bl[4],bl[5],bl[6],
 				bl[7],bl[8],bl[9],bl[10],bl[11],bl[12],bl[13],
@@ -1095,7 +1097,7 @@ void ParseKey (UWORD key, UBYTE modifier) {
 	    
 	    sb.value= &sbn;
 	    sb.low  = 0;
-	    sb.high = 1000;
+	    sb.high = 800;
 
             if (   uOpenDialog (cmds[19]+1)
                 || uAddChoiceList ("ISO8859-1 to IBM850", &cnv, c_on,c_off,NULL)
@@ -1139,8 +1141,13 @@ void ParseKey (UWORD key, UBYTE modifier) {
 			|| uRunDialog() <= 0)
 		      return;
 
-		    if(p_open(&logfd,buf+1,P_FSTREAM|P_FREPLACE|P_FUPDATE))
-		      wInfoMsgCorner(cant_open_the_file, W_CORNER_BOTTOM_RIGHT);
+		    buf[*buf+1] = 0;
+		    log = p_open(&logfd,buf+1,P_FSTREAM|P_FREPLACE|P_FUPDATE);
+		    if(log)
+		      {
+			p_atos(mfb, "open %s", buf+1);
+			Check(log, mfb);
+		      }
 		    else
 		      wInfoMsgCorner("Logging started", W_CORNER_BOTTOM_RIGHT);
 		  }
