@@ -209,8 +209,10 @@ nfsproc_getattr_2(fh)
         root_fattr.nlink = 2;
       *fp = root_fattr;
     }
-  else if(l > 4 && !strncmp(inode->name+3, "::", 2) && 
-         (l == 5 || (l == 7 && *(inode->name+6) == ':')))
+  else if( ( series5 && l == 2 && inode->name[1] == ':' ) ||
+          ( !series5 && l > 4 && inode->name[3] == ':' &&
+               inode->name[4] == ':' &&
+               (l == 5 || (l == 7 && inode->name[6] == ':'))) )
     {
       /* It's a device */
       if(debug) printf("\tgetattr:device\n");
